==> estateplat-common-1.2.3-20180110.012859-12-sources.jar: cn/gtmap/estateplat/model/employment/subject/FcjyCyztCyqyjbxx.java <==
package cn.gtmap.estateplat.model.employment.subject;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/10/25
 * @description 从业企业基本信息
 */
@Table(name = "fcjy_cyzt_cyqyjbxx")
public class FcjyCyztCyqyjbxx implements InsertVo,Serializable {
    @Id
    private String qyid;//主键
    private Long qybh;//企业编号
    private String qylb;//企业类别
    private String qymc;//企业名称
    private String qyjc;//企业简称
    private String zzjgdm;//组织机构代码
    private String szss;//所在省市
    private String qxh;//区县号
    private String jyfw;//经营范围
    private String zcdz;//注册地址
    private String lxdz;//联系地址
    private String yzbm;//邮政编码
    private String lxr;//联系人
    private String lxdh;//联系电话
    private String cz;//传真
    private String dzyj;//电子邮件
    private String wz;//网站
    private String zzdj;//资质等级
    private String zzzsbh;//资质证书编号
    private Date zzzsyxqsrq;//资质证书有效起始日期
    private Date zzzsyxzzrq;//资质证书有效终止日期
    private Integer yzczyrs;//有职称专业人数
    private Integer gjzcrs;//高级职称人数
    private Integer zcryzs;//在册人员总数
    private Integer zjzcrs;//中级职称人数
    private Integer cjzcrs;//初级职称人数
    private String yyzzhm;//营业执照号码
    private Date yyzzjyqxqsr;//营业执照经营期限起始日
    private Date yyzzjyqxdqr;//营业执照经营期限到期日
    private Double jzc;//净资产
    private Double zzc;//总资产
    private Double zczb;//注册资本
    private String zczbdw;//注册资本单位
    private String zjl;//总经理
    private String fddbr;//法定代表人
    private String frdblxdh;//法人代表联系电话
    private String frdbzjmc;//法人代表证件名称
    private String frdbzjhm;//法人代表证件号码
    private String djqxh;//登记区县号
    private Date cjsj;//创建时间
    private Date xgsj;//修改时间
    private String sfyx;//是否有效
    private String cyqyzt;//从业企业状态
    private String qyxz;//企业性质
    private Date clrq;//成立日期
    private Date pzcsfdcywrq;//批注从事房地产业务日期
    private String userid;//关联平台用户
    private String dlyhm;//登录用户名
    private String dlmm;//登录密码
    private String bazt;//备案状态
    private String bz;//备注

    public String getQyid() {
        return qyid;
    }

    public void setQyid(String qyid) {
        this.qyid = qyid;
    }

    public Long getQybh() {
        return qybh;
    }

    public void setQybh(Long qybh) {
        this.qybh = qybh;
    }

    public String getQylb() {
        return qylb;
    }

    public void setQylb(String qylb) {
        this.qylb = qylb;
    }

    public String getQymc() {
        return qymc;
    }

    public void setQymc(String qymc) {
        this.qymc = qymc;
    }

    public String getQyjc() {
        return qyjc;
    }

    public void setQyjc(String qyjc) {
        this.qyjc = qyjc;
    }

    public String getZzjgdm() {
        return zzjgdm;
    }

    public void setZzjgdm(String zzjgdm) {
        this.zzjgdm = zzjgdm;
    }

    public String getSzss() {
        return szss;
    }

    public void setSzss(String szss) {
        this.szss = szss;
    }

    public String getQxh() {
        return qxh;
    }

    public void setQxh(String qxh) {
        this.qxh = qxh;
    }

    public String getZcdz() {
        return zcdz;
    }

    public void setZcdz(String zcdz) {
        this.zcdz = zcdz;
    }

    public String getJyfw() {
        return jyfw;
    }

    public void setJyfw(String jyfw) {
        this.jyfw = jyfw;
    }

    public String getLxdz() {
        return lxdz;
    }

    public void setLxdz(String lxdz) {
        this.lxdz = lxdz;
    }

    public String getYzbm() {
        return yzbm;
    }

    public void setYzbm(String yzbm) {
        this.yzbm = yzbm;
    }

    public String getLxr() {
        return lxr;
    }

    public void setLxr(String lxr) {
        this.lxr = lxr;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getCz() {
        return cz;
    }

    public void setCz(String cz) {
        this.cz = cz;
    }

    public String getDzyj() {
        return dzyj;
    }

    public void setDzyj(String dzyj) {
        this.dzyj = dzyj;
    }

    public String getWz() {
        return wz;
    }

    public void setWz(String wz) {
        this.wz = wz;
    }

    public String getZzdj() {
        return zzdj;
    }

    public void setZzdj(String zzdj) {
        this.zzdj = zzdj;
    }

    public String getZzzsbh() {
        return zzzsbh;
    }

    public void setZzzsbh(String zzzsbh) {
        this.zzzsbh = zzzsbh;
    }

    public Date getZzzsyxqsrq() {
        return zzzsyxqsrq;
    }

    public void setZzzsyxqsrq(Date zzzsyxqsrq) {
        this.zzzsyxqsrq = zzzsyxqsrq;
    }

    public Date getZzzsyxzzrq() {
        return zzzsyxzzrq;
    }

    public void setZzzsyxzzrq(Date zzzsyxzzrq) {
        this.zzzsyxzzrq = zzzsyxzzrq;
    }

    public Integer getYzczyrs() {
        return yzczyrs;
    }

    public void setYzczyrs(Integer yzczyrs) {
        this.yzczyrs = yzczyrs;
    }

    public Integer getGjzcrs() {
        return gjzcrs;
    }

    public void setGjzcrs(Integer gjzcrs) {
        this.gjzcrs = gjzcrs;
    }

    public Integer getZcryzs() {
        return zcryzs;
    }

    public void setZcryzs(Integer zcryzs) {
        this.zcryzs = zcryzs;
    }

    public Integer getZjzcrs() {
        return zjzcrs;
    }

    public void setZjzcrs(Integer zjzcrs) {
        this.zjzcrs = zjzcrs;
    }

    public Integer getCjzcrs() {
        return cjzcrs;
    }

    public void setCjzcrs(Integer cjzcrs) {
        this.cjzcrs = cjzcrs;
    }

    public String getYyzzhm() {
        return yyzzhm;
    }

    public void setYyzzhm(String yyzzhm) {
        this.yyzzhm = yyzzhm;
    }

    public Date getYyzzjyqxqsr() {
        return yyzzjyqxqsr;
    }

    public void setYyzzjyqxqsr(Date yyzzjyqxqsr) {
        this.yyzzjyqxqsr = yyzzjyqxqsr;
    }

    public Date getYyzzjyqxdqr() {
        return yyzzjyqxdqr;
    }

    public void setYyzzjyqxdqr(Date yyzzjyqxdqr) {
        this.yyzzjyqxdqr = yyzzjyqxdqr;
    }

    public Double getJzc() {
        return jzc;
    }

    public void setJzc(Double jzc) {
        this.jzc = jzc;
    }

    public Double getZzc() {
        return zzc;
    }

    public void setZzc(Double zzc) {
        this.zzc = zzc;
    }

    public Double getZczb() {
        return zczb;
    }

    public void setZczb(Double zczb) {
        this.zczb = zczb;
    }

    public String getZczbdw() {
        return zczbdw;
    }

    public void setZczbdw(String zczbdw) {
        this.zczbdw = zczbdw;
    }

    public String getZjl() {
        return zjl;
    }

    public void setZjl(String zjl) {
        this.zjl = zjl;
    }

    public String getFddbr() {
        return fddbr;
    }

    public void setFddbr(String fddbr) {
        this.fddbr = fddbr;
    }

    public String getFrdblxdh() {
        return frdblxdh;
    }

    public void setFrdblxdh(String frdblxdh) {
        this.frdblxdh = frdblxdh;
    }

    public String getFrdbzjmc() {
        return frdbzjmc;
    }

    public void setFrdbzjmc(String frdbzjmc) {
        this.frdbzjmc = frdbzjmc;
    }

    public String getFrdbzjhm() {
        return frdbzjhm;
    }

    public void setFrdbzjhm(String frdbzjhm) {
        this.frdbzjhm = frdbzjhm;
    }

    public String getDjqxh() {
        return djqxh;
    }

    public void setDjqxh(String djqxh) {
        this.djqxh = djqxh;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public Date getXgsj() {
        return xgsj;
    }

    public void setXgsj(Date xgsj) {
        this.xgsj = xgsj;
    }

    public String getCyqyzt() {
        return cyqyzt;
    }

    public void setCyqyzt(String cyqyzt) {
        this.cyqyzt = cyqyzt;
    }

    public String getSfyx() {
        return sfyx;
    }

    public void setSfyx(String sfyx) {
        this.sfyx = sfyx;
    }

    public String getQyxz() {
        return qyxz;
    }

    public void setQyxz(String qyxz) {
        this.qyxz = qyxz;
    }

    public Date getClrq() {
        return clrq;
    }

    public void setClrq(Date clrq) {
        this.clrq = clrq;
    }

    public Date getPzcsfdcywrq() {
        return pzcsfdcywrq;
    }

    public void setPzcsfdcywrq(Date pzcsfdcywrq) {
        this.pzcsfdcywrq = pzcsfdcywrq;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getUserid() {
        return userid;
    }

    public void setUserid(String userid) {
        this.userid = userid;
    }

    public String getDlyhm() {
        return dlyhm;
    }

    public void setDlyhm(String dlyhm) {
        this.dlyhm = dlyhm;
    }

    public String getDlmm() {
        return dlmm;
    }

    public void setDlmm(String dlmm) {
        this.dlmm = dlmm;
    }

    public String getBazt() {
        return bazt;
    }

    public void setBazt(String bazt) {
        this.bazt = bazt;
    }
}

==> estateplat-common-1.2.3-20180516.013157-85-sources.jar: cn/gtmap/estateplat/model/employment/subject/FcjyCyztCyqyjbxx.java <==
package cn.gtmap.estateplat.model.employment.subject;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:liaoxiang@gtmap.cn">liaoxiang</a>
 * @version V1.0, 2017/10/25
 * @description 从业企业基本信息
 */
@Table(name = "fcjy_cyzt_cyqyjbxx")
public class FcjyCyztCyqyjbxx implements InsertVo,Serializable {
    @Id
    private String qyid;//主键
    private Long qybh;//企业编号
    private String qylb;//企业类别
    private String qymc;//企业名称
    private String qyjc;//企业简称
    private String zzjgdm;//组织机构代码
    private String szss;//所在省市
    private String qxh;//区县号
    private String jyfw;//经营范围
    private String zcdz;//注册地址
    private String lxdz;//联系地址
    private String yzbm;//邮政编码
    private String lxr;//联系人
    private String lxdh;//联系电话
    private String cz;//传真
    private String dzyj;//电子邮件
    private String wz;//网站
    private String zzdj;//资质等级
    private String zzzsbh;//资质证书编号
    private Date zzzsyxqsrq;//资质证书有效起始日期
    private Date zzzsyxzzrq;//资质证书有效终止日期
    private Integer yzczyrs;//有职称专业人数
    private Integer gjzcrs;//高级职称人数
    private Integer zcryzs;//在册人员总数
    private Integer zjzcrs;//中级职称人数
    private Integer cjzcrs;//初级职称人数
    private String yyzzhm;//营业执照号码
    private Date yyzzjyqxqsr;//营业执照经营期限起始日
    private Date yyzzjyqxdqr;//营业执照经营期限到期日
    private Double jzc;//净资产
    private Double zzc;//总资产
    private Double zczb;//注册资本
    private String zczbdw;//注册资本单位
    private String zjl;//总经理
    private String fddbr;//法定代表人
    private String frdblxdh;//法人代表联系电话
    private String frdbzjmc;//法人代表证件名称
    private String frdbzjhm;//法人代表证件号码
    private String djqxh;//登记区县号
    private Date cjsj;//创建时间
    private Date xgsj;//修改时间
    private String sfyx;//是否有效
    private String cyqyzt;//从业企业状态
    private String qyxz;//企业性质
    private Date clrq;//成立日期
    private Date pzcsfdcywrq;//批注从事房地产业务日期
    private String userid;//关联平台用户
    private String dlyhm;//登录用户名
    private String dlmm;//登录密码
    private String bazt;//备案状态
    private String bgzt;//变更状态
    private String bz;//备注


    public String getBgzt() {
        return bgzt;
    }

    public void setBgzt(String bgzt) {
        this.bgzt = bgzt;
    }

    public String getQyid() {
        return qyid;
    }

    public void setQyid(String qyid) {
        this.qyid = qyid;
    }

    public Long getQybh() {
        return qybh;
    }

    public void setQybh(Long qybh) {
        this.qybh = qybh;
    }

    public String getQylb() {
        return qylb;
    }

    public void setQylb(String qylb) {
        this.qylb = qylb;
    }

    public String getQymc() {
        return qymc;
    }

    public void setQymc(String qymc) {
        this.qymc = qymc;
    }

    public String getQyjc() {
        return qyjc;
    }

    public void setQyjc(String qyjc) {
        this.qyjc = qyjc;
    }

    public String getZzjgdm() {
        return zzjgdm;
    }

    public void setZzjgdm(String zzjgdm) {
        this.zzjgdm = zzjgdm;
    }

    public String getSzss() {
        return szss;
    }

    public void setSzss(String szss) {
        this.szss = szss;
    }

    public String getQxh() {
        return qxh;
    }

    public void setQxh(String qxh) {
        this.qxh = qxh;
    }

    public String getZcdz() {
        return zcdz;
    }

    public void setZcdz(String zcdz) {
        this.zcdz = zcdz;
    }

    public String getJyfw() {
        return jyfw;
    }

    public void setJyfw(String jyfw) {
        this.jyfw = jyfw;
    }

    public String getLxdz() {
        return lxdz;
    }

    public void setLxdz(String lxdz) {
        this.lxdz = lxdz;
    }

    public String getYzbm() {
        return yzbm;
    }

    public void setYzbm(String yzbm) {
        this.yzbm = yzbm;
    }

    public String getLxr() {
        return lxr;
    }

    public void setLxr(String lxr) {
        this.lxr = lxr;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getCz() {
        return cz;
    }

    public void setCz(String cz) {
        this.cz = cz;
    }

    public String getDzyj() {
        return dzyj;
    }

    public void setDzyj(String dzyj) {
        this.dzyj = dzyj;
    }

    public String getWz() {
        return wz;
    }

    public void setWz(String wz) {
        this.wz = wz;
    }

    public String getZzdj() {
        return zzdj;
    }

    public void setZzdj(String zzdj) {
        this.zzdj = zzdj;
    }

    public String getZzzsbh() {
        return zzzsbh;
    }

    public void setZzzsbh(String zzzsbh) {
        this.zzzsbh = zzzsbh;
    }

    public Date getZzzsyxqsrq() {
        return zzzsyxqsrq;
    }

    public void setZzzsyxqsrq(Date zzzsyxqsrq) {
        this.zzzsyxqsrq = zzzsyxqsrq;
    }

    public Date getZzzsyxzzrq() {
        return zzzsyxzzrq;
    }

    public void setZzzsyxzzrq(Date zzzsyxzzrq) {
        this.zzzsyxzzrq = zzzsyxzzrq;
    }

    public Integer getYzczyrs() {
        return yzczyrs;
    }

    public void setYzczyrs(Integer yzczyrs) {
        this.yzczyrs = yzczyrs;
    }

    public Integer getGjzcrs() {
        return gjzcrs;
    }

    public void setGjzcrs(Integer gjzcrs) {
        this.gjzcrs = gjzcrs;
    }

    public Integer getZcryzs() {
        return zcryzs;
    }

    public void setZcryzs(Integer zcryzs) {
        this.zcryzs = zcryzs;
    }

    public Integer getZjzcrs() {
        return zjzcrs;
    }

    public void setZjzcrs(Integer zjzcrs) {
        this.zjzcrs = zjzcrs;
    }

    public Integer getCjzcrs() {
        return cjzcrs;
    }

    public void setCjzcrs(Integer cjzcrs) {
        this.cjzcrs = cjzcrs;
    }

    public String getYyzzhm() {
        return yyzzhm;
    }

    public void setYyzzhm(String yyzzhm) {
        this.yyzzhm = yyzzhm;
    }

    public Date getYyzzjyqxqsr() {
        return yyzzjyqxqsr;
    }

    public void setYyzzjyqxqsr(Date yyzzjyqxqsr) {
        this.yyzzjyqxqsr = yyzzjyqxqsr;
    }

    public Date getYyzzjyqxdqr() {
        return yyzzjyqxdqr;
    }

    public void setYyzzjyqxdqr(Date yyzzjyqxdqr) {
        this.yyzzjyqxdqr = yyzzjyqxdqr;
    }

    public Double getJzc() {
        return jzc;
    }

    public void setJzc(Double jzc) {
        this.jzc = jzc;
    }

    public Double getZzc() {
        return zzc;
    }

    public void setZzc(Double zzc) {
        this.zzc = zzc;
    }

    public Double getZczb() {
        return zczb;
    }

    public void setZczb(Double zczb) {
        this.zczb = zczb;
    }

    public String getZczbdw() {
        return zczbdw;
    }

    public void setZczbdw(String zczbdw) {
        this.zczbdw = zczbdw;
    }

    public String getZjl() {
        return zjl;
    }

    public void setZjl(String zjl) {
        this.zjl = zjl;
    }

    public String getFddbr() {
        return fddbr;
    }

    public void setFddbr(String fddbr) {
        this.fddbr = fddbr;
    }

    public String getFrdblxdh() {
        return frdblxdh;
    }

    public void setFrdblxdh(String frdblxdh) {
        this.frdblxdh = frdblxdh;
    }

    public String getFrdbzjmc() {
        return frdbzjmc;
    }

    public void setFrdbzjmc(String frdbzjmc) {
        this.frdbzjmc = frdbzjmc;
    }

    public String getFrdbzjhm() {
        return frdbzjhm;
    }

    public void setFrdbzjhm(String frdbzjhm) {
        this.frdbzjhm = frdbzjhm;
    }

    public String getDjqxh() {
        return djqxh;
    }

    public void setDjqxh(String djqxh) {
        this.djqxh = djqxh;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public Date getXgsj() {
        return xgsj;
    }

    public void setXgsj(Date xgsj) {
        this.xgsj = xgsj;
    }

    public String getCyqyzt() {
        return cyqyzt;
    }

    public void setCyqyzt(String cyqyzt) {
        this.cyqyzt = cyqyzt;
    }

    public String getSfyx() {
        return sfyx;
    }

    public void setSfyx(String sfyx) {
        this.sfyx = sfyx;
    }

    public String getQyxz() {
        return qyxz;
    }

    public void setQyxz(String qyxz) {
        this.qyxz = qyxz;
    }

    public Date getClrq() {
        return clrq;
    }

    public void setClrq(Date clrq) {
        this.clrq = clrq;
    }

    public Date getPzcsfdcywrq() {
        return pzcsfdcywrq;
    }

    public void setPzcsfdcywrq(Date pzcsfdcywrq) {
        this.pzcsfdcywrq = pzcsfdcywrq;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getUserid() {
        return userid;
    }

    public void setUserid(String userid) {
        this.userid = userid;
    }

    public String getDlyhm() {
        return dlyhm;
    }

    public void setDlyhm(String dlyhm) {
        this.dlyhm = dlyhm;
    }

    public String getDlmm() {
        return dlmm;
    }

    public void setDlmm(String dlmm) {
        this.dlmm = dlmm;
    }

    public String getBazt() {
        return bazt;
    }

    public void setBazt(String bazt) {
        this.bazt = bazt;
    }
}
